## SetupInfinityHD
##
from Plugins.Plugin import PluginDescriptor
from Screens.Screen import Screen
from Screens.MessageBox import MessageBox
from Screens.Standby import TryQuitMainloop
from Components.ActionMap import ActionMap
from Components.Sources.StaticText import StaticText
from Components.Language import language
from Components.ConfigList import ConfigListScreen
from Components.config import config, ConfigYesNo, ConfigSubsection, getConfigListEntry, ConfigSelection, ConfigText, ConfigInteger
from Tools.Directories import fileExists
from Tools.LoadPixmap import LoadPixmap
from Tools.Directories import resolveFilename, SCOPE_PLUGINS, SCOPE_SKIN_IMAGE, SCOPE_LANGUAGE
from os import environ
from os import system
import gettext
import os

lang = language.getLanguage()
environ["LANGUAGE"] = lang[:2]
gettext.bindtextdomain("enigma2", resolveFilename(SCOPE_LANGUAGE))
gettext.textdomain("enigma2")
gettext.bindtextdomain("SetupInfinityHD", "%s%s" % (resolveFilename(SCOPE_PLUGINS), "Extensions/SetupInfinityHD/locale"))

def _(txt):
	t = gettext.dgettext("SetupInfinityHD", txt)
	if t == txt:
		t = gettext.gettext(txt)
	return t

config.skin.infinityhd = ConfigSubsection()
config.skin.infinityhd.channelselectionlist = ConfigSelection(default="TemplatesChannelSelectionList-2", choices = [
	("TemplatesChannelSelectionList-1", _("left")),
	("TemplatesChannelSelectionList-2", _("right"))])
config.skin.infinityhd.piconmovingchansel = ConfigSelection(default="TemplatesPiconMovingChanSel-1", choices = [
	("TemplatesPiconMovingChanSel-1", _("no")),
	("TemplatesPiconMovingChanSel-2", _("yes"))])
config.skin.infinityhd.piconmovingchansel3 = ConfigSelection(default="Templates3PiconMovingChanSel-1", choices = [
	("Templates3PiconMovingChanSel-1", _("no")),
	("Templates3PiconMovingChanSel-2", _("yes"))])
config.skin.infinityhd.vpratingchansel = ConfigSelection(default="TemplatesVpRatingChanSel-1", choices = [
	("TemplatesVpRatingChanSel-1", _("no")),
	("TemplatesVpRatingChanSel-2", _("yes"))])
config.skin.infinityhd.vpratingchansel3 = ConfigSelection(default="Templates3VpRatingChanSel-1", choices = [
	("Templates3VpRatingChanSel-1", _("no")),
	("Templates3VpRatingChanSel-2", _("yes"))])
config.skin.infinityhd.vpratingepgsel = ConfigSelection(default="TemplatesVpRatingEpgSel-1", choices = [
	("TemplatesVpRatingEpgSel-1", _("no")),
	("TemplatesVpRatingEpgSel-2", _("yes"))])
config.skin.infinityhd.vpratingeventview = ConfigSelection(default="TemplatesVpRatingEventView-1", choices = [
	("TemplatesVpRatingEventView-1", _("no")),
	("TemplatesVpRatingEventView-2", _("yes"))])
config.skin.infinityhd.rweatherinfobar = ConfigSelection(default="TemplatesRWeatherInfobar-1", choices = [
	("TemplatesRWeatherInfobar-1", _("no")),
	("TemplatesRWeatherInfobar-2", _("yes"))])
config.skin.infinityhd.changepiconsecondinf = ConfigSelection(default="TemplatesChangePiconSecondInf-1", choices = [
	("TemplatesChangePiconSecondInf-1", _("no")),
	("TemplatesChangePiconSecondInf-2", _("yes"))])
config.skin.infinityhd.scrolltextsecondinf = ConfigSelection(default="TemplatesScrollTextSecondInf-1", choices = [
	("TemplatesScrollTextSecondInf-1", _("no")),
	("TemplatesScrollTextSecondInf-2", _("yes"))])
config.skin.infinityhd.numberchannel = ConfigSelection(default="TemplatesInfoBarNumberCh-1", choices = [
	("TemplatesInfoBarNumberCh-1", _("no")),
	("TemplatesInfoBarNumberCh-2", _("yes"))])
config.skin.infinityhd.volumemy = ConfigSelection(default="Volume-1", choices = [
	("Volume-1", _("horizontal")),
	("Volume-2", _("vertical"))])

class SetupInfinityHD(ConfigListScreen, Screen):
	skin = """
	<!-- Setup InfinityHD -->
	<screen name="SetupInfinityHD" position="0,0" size="1280,720" backgroundColor="un44000000" flags="wfNoBorder" title="Setup InfinityHD">
		<panel name="ClockTemplate" />
		<eLabel position="50,100" size="1195,1" backgroundColor="crypt_emm" zPosition="2" />
		<ePixmap pixmap="InfinityHD/menu/unknown.png" position="125,110" size="300,500" />
		<widget name="config" position="540,110" size="660,500" itemHeight="36" font="Regular;24" scrollbarMode="showOnDemand" enableWrapAround="1" transparent="1" zPosition="2" />
		<widget source="version_sk" render="Label" position="155,615" size="150,22" font="Regular; 18" foregroundColor="darkgrey" backgroundColor="background" halign="left" valign="center" zPosition="4" transparent="1" />
		<widget source="vinfo_sk" render="Label" position="305,615" size="80,22" font="Regular; 18" foregroundColor="grey" backgroundColor="background" halign="left" valign="center" zPosition="4" transparent="1" />
		<widget source="key_red" render="Label" position="63,655" size="265,28" font="Regular;24" valign="center" foregroundColor="red" zPosition="3" transparent="1" />
		<widget source="key_green" render="Label" position="338,655" size="265,28" font="Regular;24" valign="center" foregroundColor="green" zPosition="3" transparent="1" />
		<widget source="key_blue" render="Label" position="888,655" size="265,28" font="Regular;24" valign="center" foregroundColor="blue" zPosition="3" transparent="1" />
		<eLabel position="50,650" size="1195,1" backgroundColor="crypt_emm" zPosition="2" />
		<widget source="Title" render="Label" position="660,60" size="400,28" font="Regular;25" halign="center" foregroundColor="unffff" backgroundColor="black" transparent="1" />
		<ePixmap pixmap="InfinityHD/buttons/button_infobig.png" position="55,660" zPosition="4" size="100,40" alphatest="on" />
		</screen>"""

	def __init__(self, session):

		Screen.__init__(self, session)
		self.session = session

		list = []
		list.append(getConfigListEntry(_("Channel list in selection"), config.skin.infinityhd.channelselectionlist))
		list.append(getConfigListEntry(_("Picon moving (right channel selection)"), config.skin.infinityhd.piconmovingchansel))
		list.append(getConfigListEntry(_("Picon moving (left channel selection)"), config.skin.infinityhd.piconmovingchansel3))
		list.append(getConfigListEntry(_("Films rating (right channel selection)"), config.skin.infinityhd.vpratingchansel))
		list.append(getConfigListEntry(_("Films rating (left channel selection)"), config.skin.infinityhd.vpratingchansel3))
		list.append(getConfigListEntry(_("Rating and poster in EPG selection"), config.skin.infinityhd.vpratingepgsel))
		list.append(getConfigListEntry(_("Rating and poster in event view"), config.skin.infinityhd.vpratingeventview))
		list.append(getConfigListEntry(_("Show weather in Infobar - geolocation"), config.skin.infinityhd.rweatherinfobar))
		list.append(getConfigListEntry(_("Change picon in second infobar"), config.skin.infinityhd.changepiconsecondinf))
		list.append(getConfigListEntry(_("Scroll text in second infobar"), config.skin.infinityhd.scrolltextsecondinf))
		list.append(getConfigListEntry(_("Channel number in second infobar"), config.skin.infinityhd.numberchannel))
		list.append(getConfigListEntry(_("Volume bars"), config.skin.infinityhd.volumemy))
		ConfigListScreen.__init__(self, list)

		self["actions"] = ActionMap(["OkCancelActions", "ColorActions", "EPGSelectActions"],{"ok": self.save, "cancel": self.exit, "red": self.exit, "green": self.save, "blue": self.install, "info": self.about}, -1)
		self["key_red"] = StaticText(_("Cancel"))
		self["key_green"] = StaticText(_("Save"))
		self["key_blue"] = StaticText(_("Install components"))
		self["Title"] = StaticText(_("Setup InfinityHD"))
		self["version_sk"] = StaticText(_("Version skin:"))
		self["vinfo_sk"] = StaticText()
		self.infosk()

	def infosk(self):
		package = 0
		global status 
		if fileExists("/usr/lib/opkg/status"):
			status = "/usr/lib/opkg/status"
		elif fileExists("/var/lib/opkg/status"):
			status = "/var/lib/opkg/status"
		elif fileExists("/var/opkg/status"):
			status = "/var/opkg/status"
		for line in open(status):
			if line.find("infinityhd") > -1:
				package = 1
			if line.find("Version:") > -1 and package == 1:
				package = 0
				try:
					self["vinfo_sk"].text = line.split()[1]
				except:
					self["vinfo_sk"].text = " "
				break

	def save(self):
		skinpath = "/usr/share/enigma2/InfinityHD/"
		pluginpath = "/usr/lib/enigma2/python/"
		channelselectionlist = config.skin.infinityhd.channelselectionlist.value
		piconmovingchansel = config.skin.infinityhd.piconmovingchansel.value
		piconmovingchansel3 = config.skin.infinityhd.piconmovingchansel3.value
		vpratingchansel = config.skin.infinityhd.vpratingchansel.value
		vpratingchansel3 = config.skin.infinityhd.vpratingchansel3.value
		vpratingepgsel = config.skin.infinityhd.vpratingepgsel.value
		vpratingeventview = config.skin.infinityhd.vpratingeventview.value
		rweatherinfobar = config.skin.infinityhd.rweatherinfobar.value
		changepiconsecondinf = config.skin.infinityhd.changepiconsecondinf.value
		scrolltextsecondinf = config.skin.infinityhd.scrolltextsecondinf.value
		numberchannel = config.skin.infinityhd.numberchannel.value
		volumemy = config.skin.infinityhd.volumemy.value
		# save config
		for x in self["config"].list:
			x[1].save()
		try:
	# default skin
			os.system("cp %sdefskin.xml %sskin.xml" % (skinpath, skinpath))
	# Channel list in selection GLOBAL setting
			os.system("sed -i 's/%s/TemplatesChannelSelectionList/w' %sskin.xml" % (channelselectionlist, skinpath))
	# Picon moving in right channel selection
			os.system("sed -i 's/%s/TemplatesPiconMovingChanSel/w' %sskin.xml" % (piconmovingchansel, skinpath))
	# Picon moving in left channel selection
			os.system("sed -i 's/%s/Templates3PiconMovingChanSel/w' %sskin.xml" % (piconmovingchansel3, skinpath))
	# Films rating in right channel selection
			os.system("sed -i 's/%s/TemplatesVpRatingChanSel/w' %sskin.xml" % (vpratingchansel, skinpath))
	# Films rating in left channel selection
			os.system("sed -i 's/%s/Templates3VpRatingChanSel/w' %sskin.xml" % (vpratingchansel3, skinpath))
	# Rating and poster in EPG selection
			os.system("sed -i 's/%s/TemplatesVpRatingEpgSel/w' %sskin.xml" % (vpratingepgsel, skinpath))
	# Rating and poster in event view
			os.system("sed -i 's/%s/TemplatesVpRatingEventView/w' %sskin.xml" % (vpratingeventview, skinpath))
	# Show weather in Infobar - geolocation
			os.system("sed -i 's/%s/TemplatesRWeatherInfobar/w' %sskin.xml" % (rweatherinfobar, skinpath))
	# Change picon in second infobar
			os.system("sed -i 's/%s/TemplatesChangePiconSecondInf/w' %sskin.xml" % (changepiconsecondinf, skinpath))
	# Scroll text in second infobar
			os.system("sed -i 's/%s/TemplatesScrollTextSecondInf/w' %sskin.xml" % (scrolltextsecondinf, skinpath))
	# Channel number in second infobar
			os.system("sed -i 's/%s/TemplatesInfoBarNumberCh/w' %sskin.xml" % (numberchannel, skinpath))
	# Volume
			os.system("sed -i 's/%s/Volume/w' %sskin.xml" % (volumemy, skinpath))
	# end
		except:
			self.session.open(MessageBox, _("Error by processing !!!"), MessageBox.TYPE_ERROR)
		self.session.openWithCallback(self.restart, MessageBox,_("Do you want to restart the GUI now ?"), MessageBox.TYPE_YESNO)

	def install(self):
		pluginpath = "/usr/lib/enigma2/python/Plugins/Extensions/SetupInfinityHD/components/"
		componentspath = "/usr/lib/enigma2/python/Components/"
		try:
	# install converter
			os.system("cp %sConverter/Bitrate2.py %sConverter/Bitrate2.py" % (pluginpath, componentspath))
			os.system("cp %sConverter/CaidInfo2.py %sConverter/CaidInfo2.py" % (pluginpath, componentspath))
			os.system("cp %sConverter/CamdInfo3.py %sConverter/CamdInfo3.py" % (pluginpath, componentspath))
			os.system("cp %sConverter/ConverterRotator.py %sConverter/ConverterRotator.py" % (pluginpath, componentspath))
			os.system("cp %sConverter/CpuUsage.py %sConverter/CpuUsage.py" % (pluginpath, componentspath))
			os.system("cp %sConverter/EmuName.py %sConverter/EmuName.py" % (pluginpath, componentspath))
			os.system("cp %sConverter/EventName2.py %sConverter/EventName2.py" % (pluginpath, componentspath))
			os.system("cp %sConverter/ExtraNumText.py %sConverter/ExtraNumText.py" % (pluginpath, componentspath))
			os.system("cp %sConverter/ExtremeInfo.py %sConverter/ExtremeInfo.py" % (pluginpath, componentspath))
			os.system("cp %sConverter/FrontendInfo2.py %sConverter/FrontendInfo2.py" % (pluginpath, componentspath))
			os.system("cp %sConverter/ProgressDiskSpaceInfo.py %sConverter/ProgressDiskSpaceInfo.py" % (pluginpath, componentspath))
			os.system("cp %sConverter/RouteInfo.py %sConverter/RouteInfo.py" % (pluginpath, componentspath))
			os.system("cp %sConverter/RWeather.py %sConverter/RWeather.py" % (pluginpath, componentspath))
			os.system("cp %sConverter/ServiceInfoEX.py %sConverter/ServiceInfoEX.py" % (pluginpath, componentspath))
			os.system("cp %sConverter/ServiceName2.py %sConverter/ServiceName2.py" % (pluginpath, componentspath))
			os.system("cp %sConverter/ServiceOrbitalPosition2.py %sConverter/ServiceOrbitalPosition2.py" % (pluginpath, componentspath))
	# install renderer
			os.system("cp %sRenderer/CoverTmbd.py %sRenderer/CoverTmbd.py" % (pluginpath, componentspath))
			os.system("cp %sRenderer/PiconUni.py %sRenderer/PiconUni.py" % (pluginpath, componentspath))
			os.system("cp %sRenderer/RatingTmbd.py %sRenderer/RatingTmbd.py" % (pluginpath, componentspath))
			os.system("cp %sRenderer/Ratingvs.py %sRenderer/Ratingvs.py" % (pluginpath, componentspath))
			os.system("cp %sRenderer/ScrollLabel.py %sRenderer/ScrollLabel.py" % (pluginpath, componentspath))
			os.system("cp %sRenderer/volumeText.py %sRenderer/volumeText.py" % (pluginpath, componentspath))
			os.system("cp %sRenderer/Watches.py %sRenderer/Watches.py" % (pluginpath, componentspath))
	# end
		except:
			self.session.open(MessageBox, _("Error by processing !!!"), MessageBox.TYPE_ERROR)
		self.session.openWithCallback(self.restart, MessageBox,_("Do you want to restart the GUI now ?"), MessageBox.TYPE_YESNO)

	def exit(self):
		for x in self["config"].list:
			x[1].cancel()
		self.close()

	def restart(self, answer):
		if answer is True:
			self.session.open(TryQuitMainloop, 3)

	def about(self):
		self.session.open(MessageBox, _("Skin InfinitiND \n\nSupport the plugin VPoiske (rating Kinopoisk.ru)"), MessageBox.TYPE_INFO)

def main(session, **kwargs):
	session.open(SetupInfinityHD)

def Plugins(**kwargs):
	return PluginDescriptor(name=_("Setup InfinityHD"),
	description=_("Setup skin InfinityHD"),
	where = [PluginDescriptor.WHERE_PLUGINMENU, PluginDescriptor.WHERE_EXTENSIONSMENU],
	icon="plugin.png",
	fnc=main)
